==> adfurikun-1.2.0.tar.gz: example/lib/interstitial_sample.dart <==
import 'dart:io';

import 'package:adfurikun/interstitial.dart';
import 'package:adfurikun_example/constants.dart';
import 'package:flutter/material.dart';

class InterstitialPage extends StatefulWidget {
  InterstitialPage({Key? key}) : super(key: key);
  @override
  InterstitialPageState createState() => InterstitialPageState();
}

class InterstitialPageState extends State<InterstitialPage> with WidgetsBindingObserver {

  String messageLog = "";
  late AdfurikunInterstitial interstitial;

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text("Interstitial Sample"),
      ),
      body: Center(
        child: Column(
          mainAxisAlignment: MainAxisAlignment.start,
          children: <Widget>[
            FractionallySizedBox(
                widthFactor: 0.9,
                child: ElevatedButton(
                    onPressed: () => load(),
                    child: Text("Load")
                )
            ),
            FractionallySizedBox(
                widthFactor: 0.9,
                child: ElevatedButton(
                    onPressed: () => show(),
                    child: Text("Show")
                )
            ),
            FractionallySizedBox(
                widthFactor: 0.9,
                child: Text(messageLog)
            ),
          ],
        ),
      ),
    );
  }

  @override
  void initState() {
    super.initState();
    WidgetsBinding.instance?.addObserver(this);
    String appId = "";
    if (Platform.isAndroid) {
      appId = ANDROID_INTERSTITIAL_APPID;
    } else {
      appId = IOS_INTERSTITIAL_APPID;
    }
    interstitial = AdfurikunInterstitial(appId);
    interstitial.listener = notifyCallback;
  }

  @override
  void dispose() {
    super.dispose();
    WidgetsBinding.instance?.removeObserver(this);
    interstitial.destroy();
    interstitial.listener = null;
  }

  @override
  void didChangeAppLifecycleState(AppLifecycleState state) {
    super.didChangeAppLifecycleState(state);
    if (AppLifecycleState.resumed == state) {
      interstitial.resume();
    } else if (AppLifecycleState.paused == state) {
      interstitial.pause();
    }
  }

  void load() {
    setState(() {
      messageLog = "動画広告の準備を開始します。" + "\n" + messageLog;
    });
    interstitial.load();
  }

  void show() async {
    bool isPrepared = await interstitial.isPrepared();
    if (isPrepared) {
      interstitial.play();
    }
  }

  void notifyCallback(AdfurikunInterstitialCallback? callback, String? appId, String? adNetworkKey, int? errorCode) {
    setState(() {
      String message = "";
      if (AdfurikunInterstitialCallback.onPrepareSuccess == callback) {
        message = "動画広告の準備が完了しました。\n";
      } else if (AdfurikunInterstitialCallback.onPrepareFailure == callback) {
        message = "動画広告の準備が失敗しました。($errorCode)\n";
      } else if (AdfurikunInterstitialCallback.onStartPlaying == callback) {
        message = "動画広告の再生を開始しました。($adNetworkKey)\n";
      } else if (AdfurikunInterstitialCallback.onFinishedPlaying == callback) {
        message = "動画広告の再生が完了しました。($adNetworkKey)\n";
      } else if (AdfurikunInterstitialCallback.onFailedPlaying == callback) {
        message = "動画広告の再生が中断しました。($adNetworkKey)\n";
      } else if (AdfurikunInterstitialCallback.onAdClose == callback) {
        message = "動画広告を閉じました。($adNetworkKey)\n";
      }
      messageLog = message + messageLog;
    });
  }
}

==> adfurikun-1.5.0.tar.gz: example/lib/interstitial_sample.dart <==
import 'dart:io';

import 'package:adfurikun/interstitial.dart';
import 'package:adfurikun_example/constants.dart';
import 'package:flutter/material.dart';

class InterstitialPage extends StatefulWidget {
  InterstitialPage({Key? key}) : super(key: key);
  @override
  InterstitialPageState createState() => InterstitialPageState();
}

class InterstitialPageState extends State<InterstitialPage> {

  String messageLog = "";
  late AdfurikunInterstitial interstitial;

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text("Interstitial Sample"),
      ),
      body: Center(
        child: Column(
          mainAxisAlignment: MainAxisAlignment.start,
          children: <Widget>[
            FractionallySizedBox(
                widthFactor: 0.9,
                child: ElevatedButton(
                    onPressed: () => load(),
                    child: Text("Load")
                )
            ),
            FractionallySizedBox(
                widthFactor: 0.9,
                child: ElevatedButton(
                    onPressed: () => show(),
                    child: Text("Show")
                )
            ),
            FractionallySizedBox(
                widthFactor: 0.9,
                child: Text(messageLog)
            ),
          ],
        ),
      ),
    );
  }

  @override
  void initState() {
    super.initState();
    String appId = "";
    if (Platform.isAndroid) {
      appId = ANDROID_INTERSTITIAL_APPID;
    } else {
      appId = IOS_INTERSTITIAL_APPID;
    }
    interstitial = AdfurikunInterstitial(appId);
    interstitial.listener = notifyCallback;
  }

  @override
  void dispose() {
    super.dispose();
    interstitial.destroy();
    interstitial.listener = null;
  }

  void load() {
    setState(() {
      messageLog = "動画広告の準備を開始します。" + "\n" + messageLog;
    });
    interstitial.load();
  }

  void show() async {
    bool isPrepared = await interstitial.isPrepared();
    if (isPrepared) {
      interstitial.play();
    }
  }

  void notifyCallback(AdfurikunInterstitialCallback? callback, String? appId, String? adNetworkKey, int? errorCode) {
    setState(() {
      String message = "";
      if (AdfurikunInterstitialCallback.onPrepareSuccess == callback) {
        message = "動画広告の準備が完了しました。\n";
      } else if (AdfurikunInterstitialCallback.onPrepareFailure == callback) {
        message = "動画広告の準備が失敗しました。($errorCode)\n";
      } else if (AdfurikunInterstitialCallback.onStartPlaying == callback) {
        message = "動画広告の再生を開始しました。($adNetworkKey)\n";
      } else if (AdfurikunInterstitialCallback.onFinishedPlaying == callback) {
        message = "動画広告の再生が完了しました。($adNetworkKey)\n";
      } else if (AdfurikunInterstitialCallback.onFailedPlaying == callback) {
        message = "動画広告の再生が中断しました。($adNetworkKey)\n";
      } else if (AdfurikunInterstitialCallback.onAdClose == callback) {
        message = "動画広告を閉じました。($adNetworkKey)\n";
      }
      messageLog = message + messageLog;
    });
  }
}
